summaryrefslogtreecommitdiff
path: root/connectivity
diff options
context:
space:
mode:
authorJan-Marek Glogowski <glogow@fbihome.de>2016-09-21 15:49:36 +0200
committerJan-Marek Glogowski <glogow@fbihome.de>2016-09-23 23:25:47 +0200
commitf486329a03b8667bd958624937f02edc9af143d1 (patch)
tree39aca9529f23fa4ab0231d7905c2554a82979abf /connectivity
parente44b034512551c09689edcecfa7401ecbb4af80e (diff)
TDE fix some clang plugin based warnings
Change-Id: I3b44038e8a889e4c13126fd8d721e53e71ea9ec6
Diffstat (limited to 'connectivity')
-rw-r--r--connectivity/source/drivers/kab/KColumns.cxx2
-rw-r--r--connectivity/source/drivers/kab/KConnection.cxx16
-rw-r--r--connectivity/source/drivers/kab/KConnection.hxx2
-rw-r--r--connectivity/source/drivers/kab/KDEInit.cxx10
-rw-r--r--connectivity/source/drivers/kab/KDatabaseMetaData.cxx180
-rw-r--r--connectivity/source/drivers/kab/KDatabaseMetaData.hxx5
-rw-r--r--connectivity/source/drivers/kab/KDriver.cxx30
-rw-r--r--connectivity/source/drivers/kab/KDriver.hxx4
-rw-r--r--connectivity/source/drivers/kab/KPreparedStatement.cxx46
-rw-r--r--connectivity/source/drivers/kab/KPreparedStatement.hxx2
-rw-r--r--connectivity/source/drivers/kab/KResultSet.cxx100
-rw-r--r--connectivity/source/drivers/kab/KResultSet.hxx4
-rw-r--r--connectivity/source/drivers/kab/KResultSetMetaData.cxx20
-rw-r--r--connectivity/source/drivers/kab/KResultSetMetaData.hxx2
-rw-r--r--connectivity/source/drivers/kab/KServices.cxx4
-rw-r--r--connectivity/source/drivers/kab/KStatement.cxx20
-rw-r--r--connectivity/source/drivers/kab/KStatement.hxx4
-rw-r--r--connectivity/source/drivers/kab/KTable.cxx28
-rw-r--r--connectivity/source/drivers/kab/KTable.hxx14
-rw-r--r--connectivity/source/drivers/kab/KTables.cxx2
-rw-r--r--connectivity/source/drivers/kab/kcondition.cxx4
-rw-r--r--connectivity/source/drivers/kab/kcondition.hxx2
-rw-r--r--connectivity/source/drivers/kab/kfields.cxx2
-rw-r--r--connectivity/source/drivers/kab/korder.hxx2
24 files changed, 253 insertions, 252 deletions
diff --git a/connectivity/source/drivers/kab/KColumns.cxx b/connectivity/source/drivers/kab/KColumns.cxx
index f15b32f4e71d..fe675ade9fcf 100644
--- a/connectivity/source/drivers/kab/KColumns.cxx
+++ b/connectivity/source/drivers/kab/KColumns.cxx
@@ -44,7 +44,7 @@ sdbcx::ObjectType KabColumns::createObject(const OUString& _rName)
Reference< XResultSet > xResult = m_pTable->getConnection()->getMetaData()->getColumns(
aCatalog, sSchemaName, sTableName, _rName);
- sdbcx::ObjectType xRet = NULL;
+ sdbcx::ObjectType xRet = nullptr;
if (xResult.is())
{
Reference< XRow > xRow(xResult,UNO_QUERY);
diff --git a/connectivity/source/drivers/kab/KConnection.cxx b/connectivity/source/drivers/kab/KConnection.cxx
index 8d6540714089..2b40d1d8bd4c 100644
--- a/connectivity/source/drivers/kab/KConnection.cxx
+++ b/connectivity/source/drivers/kab/KConnection.cxx
@@ -41,8 +41,8 @@ KabConnection::KabConnection(
css::uno::Reference<css::sdbc::XDriver> const & driver)
: OMetaConnection_BASE(m_aMutex),
OSubComponent<KabConnection, KabConnection_BASE>(driver, this),
- m_xMetaData(NULL),
- m_pAddressBook(NULL),
+ m_xMetaData(nullptr),
+ m_pAddressBook(nullptr),
m_xComponentContext(componentContext)
{}
@@ -101,7 +101,7 @@ Reference< XPreparedStatement > SAL_CALL KabConnection::prepareCall( const OUStr
checkDisposed(KabConnection_BASE::rBHelper.bDisposed);
// not implemented yet :-) a task to do
- return NULL;
+ return nullptr;
}
OUString SAL_CALL KabConnection::nativeSQL( const OUString& _sSql ) throw(SQLException, RuntimeException, std::exception)
@@ -126,7 +126,7 @@ sal_Bool SAL_CALL KabConnection::getAutoCommit( ) throw(SQLException, RuntimeEx
// you have to distinguish which if you are in autocommit mode or not
// at normal case true should be fine here
- return sal_True;
+ return true;
}
void SAL_CALL KabConnection::commit( ) throw(SQLException, RuntimeException, std::exception)
@@ -184,7 +184,7 @@ sal_Bool SAL_CALL KabConnection::isReadOnly( ) throw(SQLException, RuntimeExcep
checkDisposed(KabConnection_BASE::rBHelper.bDisposed);
// return if your connection to readonly
- return sal_False;
+ return false;
}
void SAL_CALL KabConnection::setCatalog( const OUString& ) throw(SQLException, RuntimeException, std::exception)
@@ -231,7 +231,7 @@ Reference< css::container::XNameAccess > SAL_CALL KabConnection::getTypeMap( )
// if your driver has special database types you can return it here
- return NULL;
+ return nullptr;
}
void SAL_CALL KabConnection::setTypeMap( const Reference< css::container::XNameAccess >& ) throw(SQLException, RuntimeException, std::exception)
@@ -274,10 +274,10 @@ void KabConnection::disposing()
}
m_aStatements.clear();
- if (m_pAddressBook != NULL)
+ if (m_pAddressBook != nullptr)
{
KABC::StdAddressBook::close();
- m_pAddressBook = NULL;
+ m_pAddressBook = nullptr;
}
m_xMetaData = css::uno::WeakReference< css::sdbc::XDatabaseMetaData>();
diff --git a/connectivity/source/drivers/kab/KConnection.hxx b/connectivity/source/drivers/kab/KConnection.hxx
index a9c67fe4ceee..1c6781ae070a 100644
--- a/connectivity/source/drivers/kab/KConnection.hxx
+++ b/connectivity/source/drivers/kab/KConnection.hxx
@@ -81,7 +81,7 @@ namespace connectivity
css::uno::Reference<css::uno::XComponentContext> const &
componentContext,
css::uno::Reference<css::sdbc::XDriver> const & driver);
- virtual ~KabConnection();
+ virtual ~KabConnection() override;
void closeAllStatements () throw( css::sdbc::SQLException);
diff --git a/connectivity/source/drivers/kab/KDEInit.cxx b/connectivity/source/drivers/kab/KDEInit.cxx
index 3f86512f22e7..5317c6241d4b 100644
--- a/connectivity/source/drivers/kab/KDEInit.cxx
+++ b/connectivity/source/drivers/kab/KDEInit.cxx
@@ -43,7 +43,7 @@ namespace connectivity
};
- KApplication* KDEInit::s_pKApplication = NULL;
+ KApplication* KDEInit::s_pKApplication = nullptr;
bool KDEInit::s_bDidInsertCatalogue = false;
@@ -52,9 +52,9 @@ namespace connectivity
// TODO: All this is not thread-safe
// we create a KDE application only if it is not already done
- if (KApplication::kApplication() == NULL)
+ if (KApplication::kApplication() == nullptr)
{
- OSL_ENSURE(s_pKApplication == NULL, "KDEInit::Init: inconsistency in the application pointers!");
+ OSL_ENSURE(s_pKApplication == nullptr, "KDEInit::Init: inconsistency in the application pointers!");
char *kabargs[1] = {const_cast<char*>("libkab1")};
KCmdLineArgs::init(1, kabargs, "KAddressBook", *kabargs, "Address Book driver", KAB_DRIVER_VERSION);
@@ -85,10 +85,10 @@ namespace connectivity
// which we did not previously insert
KGlobal::locale()->removeCatalogue("kaddressbook");
- if ( s_pKApplication != NULL )
+ if ( s_pKApplication != nullptr )
{
delete s_pKApplication;
- s_pKApplication = NULL;
+ s_pKApplication = nullptr;
}
}
}
diff --git a/connectivity/source/drivers/kab/KDatabaseMetaData.cxx b/connectivity/source/drivers/kab/KDatabaseMetaData.cxx
index c87e7043f8f8..644f97bc97b9 100644
--- a/connectivity/source/drivers/kab/KDatabaseMetaData.cxx
+++ b/connectivity/source/drivers/kab/KDatabaseMetaData.cxx
@@ -141,47 +141,47 @@ sal_Int32 SAL_CALL KabDatabaseMetaData::getMaxTablesInSelect( ) throw(SQLExcept
sal_Bool SAL_CALL KabDatabaseMetaData::doesMaxRowSizeIncludeBlobs( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::storesLowerCaseQuotedIdentifiers( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::storesLowerCaseIdentifiers( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::storesMixedCaseQuotedIdentifiers( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::storesMixedCaseIdentifiers( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::storesUpperCaseQuotedIdentifiers( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::storesUpperCaseIdentifiers( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsAlterTableWithAddColumn( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsAlterTableWithDropColumn( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Int32 SAL_CALL KabDatabaseMetaData::getMaxIndexLength( ) throw(SQLException, RuntimeException, std::exception)
@@ -192,7 +192,7 @@ sal_Int32 SAL_CALL KabDatabaseMetaData::getMaxIndexLength( ) throw(SQLException
sal_Bool SAL_CALL KabDatabaseMetaData::supportsNonNullableColumns( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
OUString SAL_CALL KabDatabaseMetaData::getCatalogTerm( ) throw(SQLException, RuntimeException, std::exception)
@@ -219,7 +219,7 @@ OUString SAL_CALL KabDatabaseMetaData::getExtraNameCharacters( ) throw(SQLExcep
sal_Bool SAL_CALL KabDatabaseMetaData::supportsDifferentTableCorrelationNames( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::isCatalogAtStart( ) throw(SQLException, RuntimeException, std::exception)
@@ -233,107 +233,107 @@ sal_Bool SAL_CALL KabDatabaseMetaData::isCatalogAtStart( ) throw(SQLException,
sal_Bool SAL_CALL KabDatabaseMetaData::dataDefinitionIgnoredInTransactions( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_True;
+ return true;
}
sal_Bool SAL_CALL KabDatabaseMetaData::dataDefinitionCausesTransactionCommit( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_True;
+ return true;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsDataManipulationTransactionsOnly( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_True;
+ return true;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsDataDefinitionAndDataManipulationTransactions( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_True;
+ return true;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsPositionedDelete( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsPositionedUpdate( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsOpenStatementsAcrossRollback( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsOpenStatementsAcrossCommit( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsOpenCursorsAcrossCommit( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsOpenCursorsAcrossRollback( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsTransactionIsolationLevel( sal_Int32 ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsSchemasInDataManipulation( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsANSI92FullSQL( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsANSI92EntryLevelSQL( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_True; // should be supported at least
+ return true; // should be supported at least
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsIntegrityEnhancementFacility( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsSchemasInIndexDefinitions( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsSchemasInTableDefinitions( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsCatalogsInTableDefinitions( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsCatalogsInIndexDefinitions( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsCatalogsInDataManipulation( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsOuterJoins( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Int32 SAL_CALL KabDatabaseMetaData::getMaxStatements( ) throw(SQLException, RuntimeException, std::exception)
@@ -356,198 +356,198 @@ sal_Int32 SAL_CALL KabDatabaseMetaData::getMaxSchemaNameLength( ) throw(SQLExce
sal_Bool SAL_CALL KabDatabaseMetaData::supportsTransactions( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::allProceduresAreCallable( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsStoredProcedures( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsSelectForUpdate( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::allTablesAreSelectable( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::isReadOnly( ) throw(SQLException, RuntimeException, std::exception)
{
// for the moment, we have read-only addresses, but this might change in the future
- return sal_True;
+ return true;
}
sal_Bool SAL_CALL KabDatabaseMetaData::usesLocalFiles( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::usesLocalFilePerTable( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsTypeConversion( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::nullPlusNonNullIsNull( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsColumnAliasing( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsTableCorrelationNames( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsConvert( sal_Int32, sal_Int32 ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsExpressionsInOrderBy( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsGroupBy( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsGroupByBeyondSelect( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsGroupByUnrelated( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsMultipleTransactions( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsMultipleResultSets( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsLikeEscapeClause( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsOrderByUnrelated( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsUnion( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsUnionAll( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsMixedCaseIdentifiers( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsMixedCaseQuotedIdentifiers( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::nullsAreSortedAtEnd( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::nullsAreSortedAtStart( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::nullsAreSortedHigh( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::nullsAreSortedLow( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsSchemasInProcedureCalls( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsSchemasInPrivilegeDefinitions( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsCatalogsInProcedureCalls( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsCatalogsInPrivilegeDefinitions( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsCorrelatedSubqueries( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsSubqueriesInComparisons( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsSubqueriesInExists( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsSubqueriesInIns( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsSubqueriesInQuantifieds( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsANSI92IntermediateSQL( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
OUString SAL_CALL KabDatabaseMetaData::getURL( ) throw(SQLException, RuntimeException, std::exception)
@@ -649,27 +649,27 @@ OUString SAL_CALL KabDatabaseMetaData::getNumericFunctions( ) throw(SQLExceptio
sal_Bool SAL_CALL KabDatabaseMetaData::supportsExtendedSQLGrammar( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsCoreSQLGrammar( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsMinimumSQLGrammar( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_True;
+ return true;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsFullOuterJoins( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsLimitedOuterJoins( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Int32 SAL_CALL KabDatabaseMetaData::getMaxColumnsInGroupBy( ) throw(SQLException, RuntimeException, std::exception)
@@ -702,9 +702,9 @@ sal_Bool SAL_CALL KabDatabaseMetaData::supportsResultSetType( sal_Int32 setType
{
case ResultSetType::FORWARD_ONLY:
case ResultSetType::SCROLL_INSENSITIVE:
- return sal_True;
+ return true;
}
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsResultSetConcurrency( sal_Int32 setType, sal_Int32 ) throw(SQLException, RuntimeException, std::exception)
@@ -713,59 +713,59 @@ sal_Bool SAL_CALL KabDatabaseMetaData::supportsResultSetConcurrency( sal_Int32 s
{
case ResultSetType::FORWARD_ONLY:
case ResultSetType::SCROLL_INSENSITIVE:
- return sal_True;
+ return true;
}
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::ownUpdatesAreVisible( sal_Int32 ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::ownDeletesAreVisible( sal_Int32 ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::ownInsertsAreVisible( sal_Int32 ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::othersUpdatesAreVisible( sal_Int32 ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::othersDeletesAreVisible( sal_Int32 ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::othersInsertsAreVisible( sal_Int32 ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::updatesAreDetected( sal_Int32 ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::deletesAreDetected( sal_Int32 ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::insertsAreDetected( sal_Int32 ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabDatabaseMetaData::supportsBatchUpdates( ) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
Reference< XConnection > SAL_CALL KabDatabaseMetaData::getConnection( ) throw(SQLException, RuntimeException, std::exception)
diff --git a/connectivity/source/drivers/kab/KDatabaseMetaData.hxx b/connectivity/source/drivers/kab/KDatabaseMetaData.hxx
index 3c7c927b7869..69976d1aa95e 100644
--- a/connectivity/source/drivers/kab/KDatabaseMetaData.hxx
+++ b/connectivity/source/drivers/kab/KDatabaseMetaData.hxx
@@ -21,6 +21,7 @@
#define INCLUDED_CONNECTIVITY_SOURCE_DRIVERS_KAB_KDATABASEMETADATA_HXX
#include "KConnection.hxx"
+#include <com/sun/star/sdbc/XConnection.hpp>
#include <com/sun/star/sdbc/XDatabaseMetaData.hpp>
#include <cppuhelper/implbase.hxx>
@@ -36,14 +37,14 @@ namespace connectivity
class KabDatabaseMetaData : public KabDatabaseMetaData_BASE
{
- css::uno::Reference< KabConnection > m_xConnection;
+ css::uno::Reference< css::sdbc::XConnection > m_xConnection;
bool m_bUseCatalog;
public:
explicit KabDatabaseMetaData(KabConnection* _pCon);
static const OUString & getAddressBookTableName();
- virtual ~KabDatabaseMetaData();
+ virtual ~KabDatabaseMetaData() override;
// this interface is really BIG
// XDatabaseMetaData
diff --git a/connectivity/source/drivers/kab/KDriver.cxx b/connectivity/source/drivers/kab/KDriver.cxx
index 7698d3dcd6ac..52c849270be0 100644
--- a/connectivity/source/drivers/kab/KDriver.cxx
+++ b/connectivity/source/drivers/kab/KDriver.cxx
@@ -140,11 +140,11 @@ KabImplModule::KabImplModule( const Reference< XComponentContext >& _rxContext )
:m_xContext(_rxContext)
,m_bAttemptedLoadModule(false)
,m_bAttemptedInitialize(false)
- ,m_hConnectorModule(NULL)
- ,m_pConnectionFactoryFunc(NULL)
- ,m_pApplicationInitFunc(NULL)
- ,m_pApplicationShutdownFunc(NULL)
- ,m_pKDEVersionCheckFunc(NULL)
+ ,m_hConnectorModule(nullptr)
+ ,m_pConnectionFactoryFunc(nullptr)
+ ,m_pApplicationInitFunc(nullptr)
+ ,m_pApplicationShutdownFunc(nullptr)
+ ,m_pKDEVersionCheckFunc(nullptr)
{
if ( !m_xContext.is() )
throw NullPointerException();
@@ -178,7 +178,7 @@ namespace
template< typename FUNCTION >
void lcl_getFunctionFromModuleOrUnload( oslModule& _rModule, const sal_Char* _pAsciiSymbolName, FUNCTION& _rFunction )
{
- _rFunction = NULL;
+ _rFunction = nullptr;
if ( _rModule )
{
@@ -192,7 +192,7 @@ namespace
aBuf.append( _pAsciiSymbolName );
OSL_FAIL( aBuf.makeStringAndClear().getStr() );
osl_unloadModule( _rModule );
- _rModule = NULL;
+ _rModule = nullptr;
}
}
}
@@ -204,7 +204,7 @@ extern "C" { void SAL_CALL thisModule() {} }
bool KabImplModule::impl_loadModule()
{
if ( m_bAttemptedLoadModule )
- return ( m_hConnectorModule != NULL );
+ return ( m_hConnectorModule != nullptr );
m_bAttemptedLoadModule = true;
OSL_ENSURE( !m_hConnectorModule && !m_pConnectionFactoryFunc && !m_pApplicationInitFunc && !m_pApplicationShutdownFunc && !m_pKDEVersionCheckFunc,
@@ -231,15 +231,15 @@ bool KabImplModule::impl_loadModule()
void KabImplModule::impl_unloadModule()
{
- OSL_PRECOND( m_hConnectorModule != NULL, "KabImplModule::impl_unloadModule: no module!" );
+ OSL_PRECOND( m_hConnectorModule != nullptr, "KabImplModule::impl_unloadModule: no module!" );
osl_unloadModule( m_hConnectorModule );
- m_hConnectorModule = NULL;
+ m_hConnectorModule = nullptr;
- m_pConnectionFactoryFunc = NULL;
- m_pApplicationInitFunc = NULL;
- m_pApplicationShutdownFunc = NULL;
- m_pKDEVersionCheckFunc = NULL;
+ m_pConnectionFactoryFunc = nullptr;
+ m_pApplicationInitFunc = nullptr;
+ m_pApplicationShutdownFunc = nullptr;
+ m_pKDEVersionCheckFunc = nullptr;
m_bAttemptedLoadModule = false;
}
@@ -413,7 +413,7 @@ sal_Bool SAL_CALL KabDriver::acceptsURL( const OUString& url )
::osl::MutexGuard aGuard(m_aMutex);
if ( !m_aImplModule.isKDEPresent() )
- return sal_False;
+ return false;
// here we have to look whether we support this URL format
return url.startsWith("sdbc:address:" KAB_SERVICE_NAME);
diff --git a/connectivity/source/drivers/kab/KPreparedStatement.cxx b/connectivity/source/drivers/kab/KPreparedStatement.cxx
index d37b88b4b91f..b10cb8261356 100644
--- a/connectivity/source/drivers/kab/KPreparedStatement.cxx
+++ b/connectivity/source/drivers/kab/KPreparedStatement.cxx
@@ -39,7 +39,7 @@ void KabPreparedStatement::checkAndResizeParameters(sal_Int32 nParams) throw(SQL
m_aParameterRow = new OValueVector();
if (nParams < 1)
- ::dbtools::throwInvalidIndexException(*this, Any());
+ ::dbtools::throwInvalidIndexException(*this);
if (nParams >= (sal_Int32) (m_aParameterRow->get()).size())
(m_aParameterRow->get()).resize(nParams);
@@ -56,7 +56,7 @@ void KabPreparedStatement::setKabFields() const throw(SQLException)
const OUString sError( aResources.getResourceString(
STR_INVALID_COLUMN_SELECTION
) );
- ::dbtools::throwGenericSQLException(sError,NULL);
+ ::dbtools::throwGenericSQLException(sError,nullptr);
}
m_xMetaData->setKabFields(xColumns);
}
@@ -104,7 +104,7 @@ void KabPreparedStatement::disposing()
if (m_aParameterRow.is())
{
m_aParameterRow->get().clear();
- m_aParameterRow = NULL;
+ m_aParameterRow = nullptr;
}
}
@@ -189,42 +189,42 @@ void SAL_CALL KabPreparedStatement::setNull(sal_Int32 parameterIndex, sal_Int32)
void SAL_CALL KabPreparedStatement::setObjectNull(sal_Int32, sal_Int32, const OUString&) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFunctionNotSupportedSQLException("setObjectNull", NULL);
+ ::dbtools::throwFunctionNotSupportedSQLException("setObjectNull", nullptr);
}
void SAL_CALL KabPreparedStatement::setBoolean(sal_Int32, sal_Bool) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFunctionNotSupportedSQLException("setBoolean", NULL);
+ ::dbtools::throwFunctionNotSupportedSQLException("setBoolean", nullptr);
}
void SAL_CALL KabPreparedStatement::setByte(sal_Int32, sal_Int8) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFunctionNotSupportedSQLException("setByte", NULL);
+ ::dbtools::throwFunctionNotSupportedSQLException("setByte", nullptr);
}
void SAL_CALL KabPreparedStatement::setShort(sal_Int32, sal_Int16) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFunctionNotSupportedSQLException("setShort", NULL);
+ ::dbtools::throwFunctionNotSupportedSQLException("setShort", nullptr);
}
void SAL_CALL KabPreparedStatement::setInt(sal_Int32, sal_Int32) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFunctionNotSupportedSQLException("setInt", NULL);
+ ::dbtools::throwFunctionNotSupportedSQLException("setInt", nullptr);
}
void SAL_CALL KabPreparedStatement::setLong(sal_Int32, sal_Int64) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFunctionNotSupportedSQLException("", NULL);
+ ::dbtools::throwFunctionNotSupportedSQLException("", nullptr);
}
void SAL_CALL KabPreparedStatement::setFloat(sal_Int32, float) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFunctionNotSupportedSQLException("setFloat", NULL);
+ ::dbtools::throwFunctionNotSupportedSQLException("setFloat", nullptr);
}
void SAL_CALL KabPreparedStatement::setDouble(sal_Int32, double) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFunctionNotSupportedSQLException("setDouble", NULL);
+ ::dbtools::throwFunctionNotSupportedSQLException("setDouble", nullptr);
}
void SAL_CALL KabPreparedStatement::setString(sal_Int32 parameterIndex, const OUString &x) throw(SQLException, RuntimeException, std::exception)
@@ -239,33 +239,33 @@ void SAL_CALL KabPreparedStatement::setString(sal_Int32 parameterIndex, const OU
void SAL_CALL KabPreparedStatement::setBytes(sal_Int32, const Sequence< sal_Int8 >&) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFunctionNotSupportedSQLException("setBytes", NULL);
+ ::dbtools::throwFunctionNotSupportedSQLException("setBytes", nullptr);
}
void SAL_CALL KabPreparedStatement::setDate(sal_Int32, const Date&) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFunctionNotSupportedSQLException("setDate", NULL);
+ ::dbtools::throwFunctionNotSupportedSQLException("setDate", nullptr);
}
void SAL_CALL KabPreparedStatement::setTime(sal_Int32, const css::util::Time&) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFunctionNotSupportedSQLException("setTime", NULL);
+ ::dbtools::throwFunctionNotSupportedSQLException("setTime", nullptr);
}
void SAL_CALL KabPreparedStatement::setTimestamp(sal_Int32, const DateTime&) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFunctionNotSupportedSQLException("setTimestamp", NULL);
+ ::dbtools::throwFunctionNotSupportedSQLException("setTimestamp", nullptr);
}
void SAL_CALL KabPreparedStatement::setBinaryStream(sal_Int32, const Reference< css::io::XInputStream >&, sal_Int32) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFunctionNotSupportedSQLException("setBinaryStream", NULL);
+ ::dbtools::throwFunctionNotSupportedSQLException("setBinaryStream", nullptr);
}
void SAL_CALL KabPreparedStatement::setCharacterStream(sal_Int32, const Reference< css::io::XInputStream >&, sal_Int32) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFunctionNotSupportedSQLException("setCharacterStream", NULL);
+ ::dbtools::throwFunctionNotSupportedSQLException("setCharacterStream", nullptr);
}
void SAL_CALL KabPreparedStatement::setObject(sal_Int32 parameterIndex, const Any& x) throw(SQLException, RuntimeException, std::exception)
@@ -278,32 +278,32 @@ void SAL_CALL KabPreparedStatement::setObject(sal_Int32 parameterIndex, const An
void SAL_CALL KabPreparedStatement::setObjectWithInfo(sal_Int32, const Any&, sal_Int32, sal_Int32) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFunctionNotSupportedSQLException("setObjectWithInfo", NULL);
+ ::dbtools::throwFunctionNotSupportedSQLException("setObjectWithInfo", nullptr);
}
void SAL_CALL KabPreparedStatement::setRef(sal_Int32, const Reference< XRef >&) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFunctionNotSupportedSQLException("setRef", NULL);
+ ::dbtools::throwFunctionNotSupportedSQLException("setRef", nullptr);
}
void SAL_CALL KabPreparedStatement::setBlob(sal_Int32, const Reference< XBlob >&) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFunctionNotSupportedSQLException("setBlob", NULL);
+ ::dbtools::throwFunctionNotSupportedSQLException("setBlob", nullptr);
}
void SAL_CALL KabPreparedStatement::setClob(sal_Int32, const Reference< XClob >&) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFunctionNotSupportedSQLException("setClob", NULL);
+ ::dbtools::throwFunctionNotSupportedSQLException("setClob", nullptr);
}
void SAL_CALL KabPreparedStatement::setArray(sal_Int32, const Reference< XArray >&) throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFunctionNotSupportedSQLException("setArray", NULL);
+ ::dbtools::throwFunctionNotSupportedSQLException("setArray", nullptr);
}
void SAL_CALL KabPreparedStatement::clearParameters() throw(SQLException, RuntimeException, std::exception)
{
- ::dbtools::throwFunctionNotSupportedSQLException("clearParameters", NULL);
+ ::dbtools::throwFunctionNotSupportedSQLException("clearParameters", nullptr);
}
void KabPreparedStatement::setFastPropertyValue_NoBroadcast(sal_Int32 nHandle,const Any& rValue) throw (Exception, std::exception)
diff --git a/connectivity/source/drivers/kab/KPreparedStatement.hxx b/connectivity/source/drivers/kab/KPreparedStatement.hxx
index 926ab79b2535..2b4f801232df 100644
--- a/connectivity/source/drivers/kab/KPreparedStatement.hxx
+++ b/connectivity/source/drivers/kab/KPreparedStatement.hxx
@@ -57,7 +57,7 @@ namespace connectivity
virtual void resetParameters() const throw(css::sdbc::SQLException) override;
virtual void getNextParameter(OUString &rParameter) const throw(css::sdbc::SQLException) override;
- virtual ~KabPreparedStatement();
+ virtual ~KabPreparedStatement() override;
public:
DECLARE_SERVICE_INFO();
diff --git a/connectivity/source/drivers/kab/KResultSet.hxx b/connectivity/source/drivers/kab/KResultSet.hxx
index 9b82ff8f575d..e448b710a73b 100644
--- a/connectivity/source/drivers/kab/KResultSet.hxx
+++ b/connectivity/source/drivers/kab/KResultSet.hxx
@@ -62,7 +62,7 @@ namespace connectivity
::rtl::Reference< KabResultSetMetaData > m_xMetaData; // the description of the columns in this result set
::KABC::Addressee::List m_aKabAddressees; // address book entries matching the query
sal_Int32 m_nRowPos; // the current row within the result set
- bool m_bWasNull; // last entry retrieved from this result set was NULL
+ bool m_bWasNull; // last entry retrieved from this result set was nullptr
// OPropertyArrayUsageHelper
virtual ::cppu::IPropertyArrayHelper* createArrayHelper( ) const override;
@@ -86,7 +86,7 @@ namespace connectivity
using OPropertySetHelper::getFastPropertyValue;
// you can't delete objects of this type
- virtual ~KabResultSet();
+ virtual ~KabResultSet() override;
public:
DECLARE_SERVICE_INFO();
diff --git a/connectivity/source/drivers/kab/KResultSetMetaData.cxx b/connectivity/source/drivers/kab/KResultSetMetaData.cxx
index 9d4cf0060e91..35290e538d84 100644
--- a/connectivity/source/drivers/kab/KResultSetMetaData.cxx
+++ b/connectivity/source/drivers/kab/KResultSetMetaData.cxx
@@ -69,7 +69,7 @@ sal_Int32 SAL_CALL KabResultSetMetaData::getColumnCount() throw(SQLException, Ru
sal_Bool SAL_CALL KabResultSetMetaData::isCaseSensitive(sal_Int32) throw(SQLException, RuntimeException, std::exception)
{
- return sal_True;
+ return true;
}
OUString SAL_CALL KabResultSetMetaData::getSchemaName(sal_Int32) throw(SQLException, RuntimeException, std::exception)
@@ -123,17 +123,17 @@ OUString SAL_CALL KabResultSetMetaData::getColumnServiceName(sal_Int32) throw(SQ
sal_Bool SAL_CALL KabResultSetMetaData::isCurrency(sal_Int32) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabResultSetMetaData::isAutoIncrement(sal_Int32) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabResultSetMetaData::isSigned(sal_Int32) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Int32 SAL_CALL KabResultSetMetaData::getPrecision(sal_Int32) throw(SQLException, RuntimeException, std::exception)
@@ -148,29 +148,29 @@ sal_Int32 SAL_CALL KabResultSetMetaData::getScale(sal_Int32) throw(css::sdbc::SQ
sal_Int32 SAL_CALL KabResultSetMetaData::isNullable(sal_Int32) throw(SQLException, RuntimeException, std::exception)
{
- return (sal_Int32) sal_True;
-// KDE address book currently does not use NULL values.
+ return (sal_Int32) true;
+// KDE address book currently does not use nullptr values.
// But it might do it someday
}
sal_Bool SAL_CALL KabResultSetMetaData::isSearchable(sal_Int32) throw(SQLException, RuntimeException, std::exception)
{
- return sal_True;
+ return true;
}
sal_Bool SAL_CALL KabResultSetMetaData::isReadOnly(sal_Int32) throw(SQLException, RuntimeException, std::exception)
{
- return sal_True;
+ return true;
}
sal_Bool SAL_CALL KabResultSetMetaData::isDefinitelyWritable(sal_Int32) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabResultSetMetaData::isWritable(sal_Int32) throw(SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
diff --git a/connectivity/source/drivers/kab/KResultSetMetaData.hxx b/connectivity/source/drivers/kab/KResultSetMetaData.hxx
index dd2bcd90e7ad..557a289aa11f 100644
--- a/connectivity/source/drivers/kab/KResultSetMetaData.hxx
+++ b/connectivity/source/drivers/kab/KResultSetMetaData.hxx
@@ -40,7 +40,7 @@ namespace connectivity
// of the corresponding KAddressBook field
protected:
- virtual ~KabResultSetMetaData();
+ virtual ~KabResultSetMetaData() override;
public:
KabResultSetMetaData();
diff --git a/connectivity/source/drivers/kab/KServices.cxx b/connectivity/source/drivers/kab/KServices.cxx
index c4d9618ea29a..6c2c9fe9723b 100644
--- a/connectivity/source/drivers/kab/KServices.cxx
+++ b/connectivity/source/drivers/kab/KServices.cxx
@@ -71,7 +71,7 @@ struct ProviderRequest
{
try
{
- xRet = creator( xServiceManager, sImplementationName,Factory, Services,0);
+ xRet = creator( xServiceManager, sImplementationName,Factory, Services, nullptr);
}
catch(...)
{
@@ -89,7 +89,7 @@ extern "C" SAL_DLLPUBLIC_EXPORT void* SAL_CALL kab_component_getFactory(
void* pServiceManager,
void*)
{
- void* pRet = 0;
+ void* pRet = nullptr;
if (pServiceManager)
{
ProviderRequest aReq(pServiceManager,pImplementationName);
diff --git a/connectivity/source/drivers/kab/KStatement.hxx b/connectivity/source/drivers/kab/KStatement.hxx
index 1cac8d4495d1..31907fdca3d7 100644
--- a/connectivity/source/drivers/kab/KStatement.hxx
+++ b/connectivity/source/drivers/kab/KStatement.hxx
@@ -88,7 +88,7 @@ namespace connectivity
virtual void resetParameters() const throw(css::sdbc::SQLException);
virtual void getNextParameter(OUString &rParameter) const throw(css::sdbc::SQLException);
- virtual ~KabCommonStatement();
+ virtual ~KabCommonStatement() override;
public:
::cppu::OBroadcastHelper& rBHelper;
@@ -148,7 +148,7 @@ namespace connectivity
class KabStatement : public KabStatement_BASE
{
protected:
- virtual ~KabStatement() { }
+ virtual ~KabStatement() override { }
public:
explicit KabStatement(KabConnection* _pConnection);
diff --git a/connectivity/source/drivers/kab/KTable.cxx b/connectivity/source/drivers/kab/KTable.cxx
index cdcd7d211d99..ceac4b08c93c 100644
--- a/connectivity/source/drivers/kab/KTable.cxx
+++ b/connectivity/source/drivers/kab/KTable.cxx
@@ -34,20 +34,20 @@ using namespace ::com::sun::star::container;
using namespace ::com::sun::star::lang;
-KabTable::KabTable( sdbcx::OCollection* _pTables,
- KabConnection* _pConnection,
- const OUString& _Name,
- const OUString& _Type,
- const OUString& _Description ,
- const OUString& _SchemaName,
- const OUString& _CatalogName
- ) : KabTable_TYPEDEF(_pTables,true,
- _Name,
- _Type,
- _Description,
- _SchemaName,
- _CatalogName),
- m_pConnection(_pConnection)
+KabTable::KabTable( sdbcx::OCollection* pTables,
+ KabConnection* pConnection,
+ const OUString& Name,
+ const OUString& Type,
+ const OUString& Description ,
+ const OUString& SchemaName,
+ const OUString& CatalogName
+ ) : KabTable_TYPEDEF(pTables,true,
+ Name,
+ Type,
+ Description,
+ SchemaName,
+ CatalogName),
+ m_pConnection(pConnection)
{
construct();
}
diff --git a/connectivity/source/drivers/kab/KTable.hxx b/connectivity/source/drivers/kab/KTable.hxx
index a2b27522c362..706715126f02 100644
--- a/connectivity/source/drivers/kab/KTable.hxx
+++ b/connectivity/source/drivers/kab/KTable.hxx
@@ -35,13 +35,13 @@ namespace connectivity
KabConnection* m_pConnection;
public:
- KabTable( sdbcx::OCollection* _pTables,
- KabConnection* _pConnection,
- const OUString& _Name,
- const OUString& _Type,
- const OUString& _Description = OUString(),
- const OUString& _SchemaName = OUString(),
- const OUString& _CatalogName = OUString()
+ KabTable( sdbcx::OCollection* pTables,
+ KabConnection* pConnection,
+ const OUString& Name,
+ const OUString& Type,
+ const OUString& Description = OUString(),
+ const OUString& SchemaName = OUString(),
+ const OUString& CatalogName = OUString()
);
KabConnection* getConnection() { return m_pConnection;}
diff --git a/connectivity/source/drivers/kab/KTables.cxx b/connectivity/source/drivers/kab/KTables.cxx
index 085b34b2acd1..6d725e6101e8 100644
--- a/connectivity/source/drivers/kab/KTables.cxx
+++ b/connectivity/source/drivers/kab/KTables.cxx
@@ -45,7 +45,7 @@ sdbcx::ObjectType KabTables::createObject(const OUString& _rName)
Reference< XResultSet > xResult = m_xMetaData->getTables(Any(), aSchema, aName, aTypes);
- sdbcx::ObjectType xRet = NULL;
+ sdbcx::ObjectType xRet = nullptr;
if (xResult.is())
{
Reference< XRow > xRow(xResult, UNO_QUERY);
diff --git a/connectivity/source/drivers/kab/kcondition.cxx b/connectivity/source/drivers/kab/kcondition.cxx
index a21154d2f925..5801a454a062 100644
--- a/connectivity/source/drivers/kab/kcondition.cxx
+++ b/connectivity/source/drivers/kab/kcondition.cxx
@@ -78,7 +78,7 @@ bool KabConditionNull::eval(const ::KABC::Addressee &aAddressee) const
QString aQtName = valueOfKabField(aAddressee, m_nFieldNumber);
return aQtName.isNull();
-// KDE address book currently does not use NULL values.
+// KDE address book currently does not use nullptr values.
// But it might do it someday
}
@@ -92,7 +92,7 @@ bool KabConditionNotNull::eval(const ::KABC::Addressee &aAddressee) const
QString aQtName = valueOfKabField(aAddressee, m_nFieldNumber);
return !aQtName.isNull();
-// KDE address book currently does not use NULL values.
+// KDE address book currently does not use nullptr values.
// But it might do it someday
}
diff --git a/connectivity/source/drivers/kab/kcondition.hxx b/connectivity/source/drivers/kab/kcondition.hxx
index 30eb4b9c50ec..a6b1cd8808b6 100644
--- a/connectivity/source/drivers/kab/kcondition.hxx
+++ b/connectivity/source/drivers/kab/kcondition.hxx
@@ -125,7 +125,7 @@ class KabConditionBoolean : public KabCondition
public:
KabConditionBoolean(KabCondition *pLeft, KabCondition *pRight);
- virtual ~KabConditionBoolean();
+ virtual ~KabConditionBoolean() override;
};
class KabConditionOr : public KabConditionBoolean
diff --git a/connectivity/source/drivers/kab/kfields.cxx b/connectivity/source/drivers/kab/kfields.cxx
index d19f1caebcb2..0ecc78ae5c23 100644
--- a/connectivity/source/drivers/kab/kfields.cxx
+++ b/connectivity/source/drivers/kab/kfields.cxx
@@ -77,7 +77,7 @@ sal_uInt32 findKabField(const OUString& columnName) throw(SQLException)
STR_INVALID_COLUMNNAME,
"$columnname$",columnName
) );
- ::dbtools::throwGenericSQLException(sError,NULL);
+ ::dbtools::throwGenericSQLException(sError,nullptr);
// Unreachable:
OSL_ASSERT(false);
return 0;
diff --git a/connectivity/source/drivers/kab/korder.hxx b/connectivity/source/drivers/kab/korder.hxx
index 4f8b7871cad7..6bcc6aab5b10 100644
--- a/connectivity/source/drivers/kab/korder.hxx
+++ b/connectivity/source/drivers/kab/korder.hxx
@@ -55,7 +55,7 @@ namespace connectivity
public:
KabComplexOrder();
- virtual ~KabComplexOrder();
+ virtual ~KabComplexOrder() override;
void addOrder(KabOrder *pOrder);
virtual sal_Int32 compare(const ::KABC::Addressee &aAddressee1, const ::KABC::Addressee &aAddressee2) const override;
diff --git a/connectivity/source/drivers/kab/KDriver.hxx b/connectivity/source/drivers/kab/KDriver.hxx
index 5174c90a0968..b061b0040668 100644
--- a/connectivity/source/drivers/kab/KDriver.hxx
+++ b/connectivity/source/drivers/kab/KDriver.hxx
@@ -117,8 +117,8 @@ namespace connectivity
*/
bool impl_loadModule();
- /** unloads the implementation module, and resets all function pointers to <NULL/>
- @precond m_hConnectorModule is not <NULL/>
+ /** unloads the implementation module, and resets all function pointers to <nullptr/>
+ @precond m_hConnectorModule is not <nullptr/>
*/
void impl_unloadModule();
diff --git a/connectivity/source/drivers/kab/KResultSet.cxx b/connectivity/source/drivers/kab/KResultSet.cxx
index 3c49289a76a0..8babcb4714e3 100644
--- a/connectivity/source/drivers/kab/KResultSet.cxx
+++ b/connectivity/source/drivers/kab/KResultSet.cxx
@@ -48,7 +48,7 @@ KabResultSet::KabResultSet(KabCommonStatement* pStmt)
: KabResultSet_BASE(m_aMutex),
OPropertySetHelper(KabResultSet_BASE::rBHelper),
m_xStatement(pStmt),
- m_xMetaData(NULL),
+ m_xMetaData(nullptr),
m_aKabAddressees(),
m_nRowPos(-1),
m_bWasNull(true)
@@ -192,7 +192,7 @@ return aRet;
default:
aQtName = aFields[nFieldNumber - KAB_DATA_FIELDS]->value(m_aKabAddressees[m_nRowPos]);
}
// KDE address book currently does not use NULL values.
// But it might do it someday
if (!aQtName.isNull())
{
@@ -211,9 +211,9 @@ sal_Bool SAL_CALL KabResultSet::getBoolean(sal_Int32) throw(SQLException, Runtim
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(KabResultSet_BASE::rBHelper.bDisposed);
-::dbtools::throwFunctionNotSupportedSQLException("getBoolean", NULL);
+::dbtools::throwFunctionNotSupportedSQLException("getBoolean", nullptr);
- return sal_False;
+ return false;
}
sal_Int8 SAL_CALL KabResultSet::getByte(sal_Int32) throw(SQLException, RuntimeException, std::exception)
@@ -221,7 +221,7 @@ sal_Int8 SAL_CALL KabResultSet::getByte(sal_Int32) throw(SQLException, RuntimeEx
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(KabResultSet_BASE::rBHelper.bDisposed);
-::dbtools::throwFunctionNotSupportedSQLException("getByte", NULL);
+::dbtools::throwFunctionNotSupportedSQLException("getByte", nullptr);
sal_Int8 nRet = 0;
return nRet;
@@ -232,7 +232,7 @@ sal_Int16 SAL_CALL KabResultSet::getShort(sal_Int32) throw(SQLException, Runtime
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(KabResultSet_BASE::rBHelper.bDisposed);
-::dbtools::throwFunctionNotSupportedSQLException("getShort", NULL);
+::dbtools::throwFunctionNotSupportedSQLException("getShort", nullptr);
sal_Int16 nRet = 0;
return nRet;
@@ -243,7 +243,7 @@ sal_Int32 SAL_CALL KabResultSet::getInt(sal_Int32) throw(SQLException, RuntimeEx
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(KabResultSet_BASE::rBHelper.bDisposed);
-::dbtools::throwFunctionNotSupportedSQLException("getInt", NULL);
+::dbtools::throwFunctionNotSupportedSQLException("getInt", nullptr);
sal_Int32 nRet = 0;
return nRet;
@@ -254,7 +254,7 @@ sal_Int64 SAL_CALL KabResultSet::getLong(sal_Int32) throw(SQLException, RuntimeE
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(KabResultSet_BASE::rBHelper.bDisposed);
-::dbtools::throwFunctionNotSupportedSQLException("getLong", NULL);
+::dbtools::throwFunctionNotSupportedSQLException("getLong", nullptr);
return sal_Int64();
}
@@ -264,7 +264,7 @@ float SAL_CALL KabResultSet::getFloat(sal_Int32) throw(SQLException, RuntimeExce
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(KabResultSet_BASE::rBHelper.bDisposed);
-::dbtools::throwFunctionNotSupportedSQLException("getFloat", NULL);
+::dbtools::throwFunctionNotSupportedSQLException("getFloat", nullptr);
float nVal(0);
return nVal;
@@ -275,7 +275,7 @@ double SAL_CALL KabResultSet::getDouble(sal_Int32) throw(SQLException, RuntimeEx
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(KabResultSet_BASE::rBHelper.bDisposed);
-::dbtools::throwFunctionNotSupportedSQLException("getDouble", NULL);
+::dbtools::throwFunctionNotSupportedSQLException("getDouble", nullptr);
double nRet = 0;
return nRet;
@@ -286,7 +286,7 @@ Sequence< sal_Int8 > SAL_CALL KabResultSet::getBytes(sal_Int32) throw(SQLExcepti
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(KabResultSet_BASE::rBHelper.bDisposed);
-::dbtools::throwFunctionNotSupportedSQLException("", NULL);
+::dbtools::throwFunctionNotSupportedSQLException("", nullptr);
return Sequence< sal_Int8 >();
}
@@ -296,7 +296,7 @@ cssu::Date SAL_CALL KabResultSet::getDate(sal_Int32) throw(SQLException, Runtime
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(KabResultSet_BASE::rBHelper.bDisposed);
-::dbtools::throwFunctionNotSupportedSQLException("getDate", NULL);
+::dbtools::throwFunctionNotSupportedSQLException("getDate", nullptr);
cssu::Date aRet;
return aRet;
@@ -307,7 +307,7 @@ cssu::Time SAL_CALL KabResultSet::getTime(sal_Int32) throw(SQLException, Runtime
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(KabResultSet_BASE::rBHelper.bDisposed);
-::dbtools::throwFunctionNotSupportedSQLException("getTime", NULL);
+::dbtools::throwFunctionNotSupportedSQLException("getTime", nullptr);
cssu::Time nRet;
return nRet;
@@ -357,9 +357,9 @@ Reference< XInputStream > SAL_CALL KabResultSet::getBinaryStream(sal_Int32) thro
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(KabResultSet_BASE::rBHelper.bDisposed);
-::dbtools::throwFunctionNotSupportedSQLException("getBinaryStream", NULL);
+::dbtools::throwFunctionNotSupportedSQLException("getBinaryStream", nullptr);
- return NULL;
+ return nullptr;
}
Reference< XInputStream > SAL_CALL KabResultSet::getCharacterStream(sal_Int32) throw(SQLException, RuntimeException, std::exception)
@@ -367,9 +367,9 @@ Reference< XInputStream > SAL_CALL KabResultSet::getCharacterStream(sal_Int32) t
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(KabResultSet_BASE::rBHelper.bDisposed);
-::dbtools::throwFunctionNotSupportedSQLException("getCharacterStream", NULL);
+::dbtools::throwFunctionNotSupportedSQLException("getCharacterStream", nullptr);
- return NULL;
+ return nullptr;
}
Any SAL_CALL KabResultSet::getObject(sal_Int32, const Reference< css::container::XNameAccess >&) throw(SQLException, RuntimeException, std::exception)
@@ -377,7 +377,7 @@ Any SAL_CALL KabResultSet::getObject(sal_Int32, const Reference< css::container:
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(KabResultSet_BASE::rBHelper.bDisposed);
-::dbtools::throwFunctionNotSupportedSQLException("getObject", NULL);
+::dbtools::throwFunctionNotSupportedSQLException("getObject", nullptr);
return Any();
}
@@ -387,9 +387,9 @@ Reference< XRef > SAL_CALL KabResultSet::getRef(sal_Int32) throw(SQLException, R
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(KabResultSet_BASE::rBHelper.bDisposed);
-::dbtools::throwFunctionNotSupportedSQLException("getRef", NULL);
+::dbtools::throwFunctionNotSupportedSQLException("getRef", nullptr);
- return NULL;
+ return nullptr;
}
Reference< XBlob > SAL_CALL KabResultSet::getBlob(sal_Int32) throw(SQLException, RuntimeException, std::exception)
@@ -397,9 +397,9 @@ Reference< XBlob > SAL_CALL KabResultSet::getBlob(sal_Int32) throw(SQLException,
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(KabResultSet_BASE::rBHelper.bDisposed);
-::dbtools::throwFunctionNotSupportedSQLException("getBlob", NULL);
+::dbtools::throwFunctionNotSupportedSQLException("getBlob", nullptr);
- return NULL;
+ return nullptr;
}
Reference< XClob > SAL_CALL KabResultSet::getClob(sal_Int32) throw(SQLException, RuntimeException, std::exception)
@@ -407,9 +407,9 @@ Reference< XClob > SAL_CALL KabResultSet::getClob(sal_Int32) throw(SQLException,
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(KabResultSet_BASE::rBHelper.bDisposed);
-::dbtools::throwFunctionNotSupportedSQLException("getClob", NULL);
+::dbtools::throwFunctionNotSupportedSQLException("getClob", nullptr);
- return NULL;
+ return nullptr;
}
Reference< XArray > SAL_CALL KabResultSet::getArray(sal_Int32) throw(SQLException, RuntimeException, std::exception)
@@ -417,9 +417,9 @@ Reference< XArray > SAL_CALL KabResultSet::getArray(sal_Int32) throw(SQLExceptio
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(KabResultSet_BASE::rBHelper.bDisposed);
-::dbtools::throwFunctionNotSupportedSQLException("getArray", NULL);
+::dbtools::throwFunctionNotSupportedSQLException("getArray", nullptr);
- return NULL;
+ return nullptr;
}
Reference< XResultSetMetaData > SAL_CALL KabResultSet::getMetaData() throw(SQLException, RuntimeException, std::exception)
@@ -440,9 +440,9 @@ sal_Bool SAL_CALL KabResultSet::isBeforeFirst() throw(SQLException, RuntimeExcep
checkDisposed(KabResultSet_BASE::rBHelper.bDisposed);
if (m_nRowPos == -1)
- return sal_True;
+ return true;
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabResultSet::isAfterLast() throw(SQLException, RuntimeException, std::exception)
@@ -452,9 +452,9 @@ sal_Bool SAL_CALL KabResultSet::isAfterLast() throw(SQLException, RuntimeExcepti
sal_Int32 nAddressees = m_aKabAddressees.size();
if (m_nRowPos == nAddressees)
- return sal_True;
+ return true;
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabResultSet::isFirst() throw(SQLException, RuntimeException, std::exception)
@@ -463,9 +463,9 @@ sal_Bool SAL_CALL KabResultSet::isFirst() throw(SQLException, RuntimeException,
checkDisposed(KabResultSet_BASE::rBHelper.bDisposed);
if (m_nRowPos == 0)
- return sal_True;
+ return true;
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabResultSet::isLast() throw(SQLException, RuntimeException, std::exception)
@@ -475,9 +475,9 @@ sal_Bool SAL_CALL KabResultSet::isLast() throw(SQLException, RuntimeException, s
sal_Int32 nAddressees = m_aKabAddressees.size();
if (m_nRowPos == nAddressees - 1)
- return sal_True;
+ return true;
- return sal_False;
+ return false;
}
void SAL_CALL KabResultSet::beforeFirst() throw(SQLException, RuntimeException, std::exception)
@@ -515,10 +515,10 @@ sal_Bool SAL_CALL KabResultSet::first() throw(SQLException, RuntimeException, st
sal_Int32 nAddressees = m_aKabAddressees.size();
if (nAddressees == 0)
- return sal_False;
+ return false;
m_nRowPos = 0;
- return sal_True;
+ return true;
}
sal_Bool SAL_CALL KabResultSet::last() throw(SQLException, RuntimeException, std::exception)
@@ -528,10 +528,10 @@ sal_Bool SAL_CALL KabResultSet::last() throw(SQLException, RuntimeException, std
sal_Int32 nAddressees = m_aKabAddressees.size();
if (nAddressees == 0)
- return sal_False;
+ return false;
m_nRowPos = nAddressees - 1;
- return sal_True;
+ return true;
}
sal_Int32 SAL_CALL KabResultSet::getRow() throw(SQLException, RuntimeException, std::exception)
@@ -550,10 +550,10 @@ sal_Bool SAL_CALL KabResultSet::absolute(sal_Int32 row) throw(SQLException, Runt
sal_Int32 nAddressees = m_aKabAddressees.size();
if (row <= -1 ||
row >= nAddressees)
- return sal_False;
+ return false;
m_nRowPos = row;
- return sal_True;
+ return true;
}
sal_Bool SAL_CALL KabResultSet::relative(sal_Int32 row) throw(SQLException, RuntimeException, std::exception)
@@ -594,7 +594,7 @@ sal_Bool SAL_CALL KabResultSet::rowDeleted() throw(SQLException, RuntimeExceptio
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(KabResultSet_BASE::rBHelper.bDisposed);
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabResultSet::rowInserted() throw(SQLException, RuntimeException, std::exception)
@@ -602,7 +602,7 @@ sal_Bool SAL_CALL KabResultSet::rowInserted() throw(SQLException, RuntimeExcepti
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(KabResultSet_BASE::rBHelper.bDisposed);
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabResultSet::rowUpdated() throw(SQLException, RuntimeException, std::exception)
@@ -610,7 +610,7 @@ sal_Bool SAL_CALL KabResultSet::rowUpdated() throw(SQLException, RuntimeExceptio
::osl::MutexGuard aGuard( m_aMutex );
checkDisposed(KabResultSet_BASE::rBHelper.bDisposed);
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabResultSet::wasNull() throw(SQLException, RuntimeException, std::exception)
@@ -819,10 +819,10 @@ sal_Bool SAL_CALL KabResultSet::moveToBookmark(const Any& bookmark) throw( SQLE
if (sUniqueIdentifier == sBookmark)
{
m_nRowPos = nRow;
- return sal_True;
+ return true;
}
}
- return sal_False;
+ return false;
}
sal_Bool SAL_CALL KabResultSet::moveRelativeToBookmark(const Any& bookmark, sal_Int32 rows) throw( SQLException, RuntimeException, std::exception)
@@ -839,11 +839,11 @@ sal_Bool SAL_CALL KabResultSet::moveRelativeToBookmark(const Any& bookmark, sal
m_nRowPos += rows;
if (-1 < m_nRowPos && m_nRowPos < nAddressees)
- return sal_True;
+ return true;
}
m_nRowPos = nRowSave;
- return sal_False;
+ return false;
}
sal_Int32 SAL_CALL KabResultSet::compareBookmarks(const Any& firstItem, const Any& secondItem) throw( SQLException, RuntimeException, std::exception)
@@ -863,7 +863,7 @@ sal_Int32 SAL_CALL KabResultSet::compareBookmarks(const Any& firstItem, const
sal_Bool SAL_CALL KabResultSet::hasOrderedBookmarks() throw( SQLException, RuntimeException, std::exception)
{
- return sal_False;
+ return false;
}
sal_Int32 SAL_CALL KabResultSet::hashBookmark(const Any& bookmark) throw( SQLException, RuntimeException, std::exception)
@@ -913,7 +913,7 @@ IPropertyArrayHelper* KabResultSet::createArrayHelper() const
IPropertyArrayHelper & KabResultSet::getInfoHelper()
{
- return *static_cast<KabResultSet*>(this)->getArrayHelper();
+ return *(this->getArrayHelper());
}
sal_Bool KabResultSet::convertFastPropertyValue(
@@ -936,7 +936,7 @@ sal_Bool KabResultSet::convertFastPropertyValue(
default:
;
}
- return sal_False;
+ return false;
}
void KabResultSet::setFastPropertyValue_NoBroadcast(
@@ -192,7 +192,7 @@ return aRet;
aQtName = aFields[nFieldNumber - KAB_DATA_FIELDS]->value(m_aKabAddressees[m_nRowPos]);
}
-// KDE address book currently does not use NULL values.
+// KDE address book currently does not use nullptr values.
// But it might do it someday
if (!aQtName.isNull())
diff --git a/connectivity/source/drivers/kab/KStatement.cxx b/connectivity/source/drivers/kab/KStatement.cxx
index c5328708d919..51ed99c6675a 100644
--- a/connectivity/source/drivers/kab/KStatement.cxx
+++ b/connectivity/source/drivers/kab/KStatement.cxx
@@ -54,7 +54,7 @@ namespace
{
::connectivity::SharedResources aResources;
const OUString sError( aResources.getResourceString(_nErrorId) );
- ::dbtools::throwGenericSQLException(sError,NULL);
+ ::dbtools::throwGenericSQLException(sError,nullptr);
}
}
@@ -64,8 +64,8 @@ KabCommonStatement::KabCommonStatement(KabConnection* _pConnection )
: KabCommonStatement_BASE(m_aMutex),
OPropertySetHelper(KabCommonStatement_BASE::rBHelper),
m_aParser(_pConnection->getComponentContext()),
- m_aSQLIterator(_pConnection, _pConnection->createCatalog()->getTables(), m_aParser, NULL ),
- m_pParseTree(NULL),
+ m_aSQLIterator(_pConnection, _pConnection->createCatalog()->getTables(), m_aParser, nullptr ),
+ m_pParseTree(nullptr),
m_pConnection(_pConnection),
rBHelper(KabCommonStatement_BASE::rBHelper)
{
@@ -197,12 +197,12 @@ KabCondition *KabCommonStatement::analyseWhereClause(const OSQLParseNode *pParse
if (SQL_ISTOKEN(pMiddleRight, NOT))
{
// WHERE "Mobile Phone" IS NOT NULL
return new KabConditionNotNull(sColumnName);
}
else
{
// WHERE "Mobile Phone" IS NULL
return new KabConditionNull(sColumnName);
}
}
@@ -235,7 +235,7 @@ KabCondition *KabCommonStatement::analyseWhereClause(const OSQLParseNode *pParse
// Unreachable:
OSL_ASSERT(false);
- return 0;
+ return nullptr;
}
KabOrder *KabCommonStatement::analyseOrderByClause(const OSQLParseNode *pParseNode) const throw(SQLException)
@@ -281,7 +281,7 @@ KabOrder *KabCommonStatement::analyseOrderByClause(const OSQLParseNode *pParseNo
lcl_throwError(STR_QUERY_TOO_COMPLEX);
// Unreachable:
OSL_ASSERT(false);
- return 0;
+ return nullptr;
}
bool KabCommonStatement::isTableKnown(KabResultSet *pResult) const
@@ -314,7 +314,7 @@ void KabCommonStatement::selectAddressees(KabResultSet *pResult) const throw(SQL
const OSQLParseNode *pParseNode;
pParseNode = m_aSQLIterator.getWhereTree();
- if (pParseNode != NULL)
+ if (pParseNode != nullptr)
{
if (SQL_ISRULE(pParseNode, where_clause))
{
@@ -339,7 +339,7 @@ void KabCommonStatement::sortAddressees(KabResultSet *pResult) const throw(SQLEx
const OSQLParseNode *pParseNode;
pParseNode = m_aSQLIterator.getOrderTree();
- if (pParseNode != NULL)
+ if (pParseNode != nullptr)
{
if (SQL_ISRULE(pParseNode, opt_order_by_clause))
{
@@ -410,7 +410,7 @@ OSL_TRACE("KDE Address book - SQL Request: %s", OUtoCStr(sql));
OUString aErr;
m_pParseTree = m_aParser.parseTree(aErr, sql);
- if (m_pParseTree == NULL)
+ if (m_pParseTree == nullptr)
throw SQLException(aErr, *this, aErr, 0, Any());
m_aSQLIterator.setParseTree(m_pParseTree);
@@ -197,12 +197,12 @@ KabCondition *KabCommonStatement::analyseWhereClause(const OSQLParseNode *pParse
if (SQL_ISTOKEN(pMiddleRight, NOT))
{
- // WHERE "Mobile Phone" IS NOT NULL
+ // WHERE "Mobile Phone" IS NOT nullptr
return new KabConditionNotNull(sColumnName);
}
@@ -197,12 +197,12 @@ KabCondition *KabCommonStatement::analyseWhereClause(const OSQLParseNode *pParse
else
{
- // WHERE "Mobile Phone" IS NULL
+ // WHERE "Mobile Phone" IS nullptr
return new KabConditionNull(sColumnName);
}